/* 

	CTermPane.h
	
	Commtoolbox terminal emulation class.
	
	SUPERCLASS = CPanorama.
	
	Copyright  1992-93 Romain Vignes. All rights reserved.
	
 */

#define _H_CTermPane


#include <Terminals.h>				/* Apple includes */

#include <CPanorama.h>				/* Interface for its superclass */

/* Constants & Macros */

#define EMPTY_STR			0L


/* Terminal specific commands */

#define cmdTermChoose		2200	/* Terminal tool setup */
#define cmdTermClear		2201	/* Screen clearing */
#define cmdTermReset		2202	/* Terminal reset */
#define cmdTabCopy			2203	/* Table copy */


/* Broadcast indications */

enum	{
	termSizeChangedInd = 2201		/* Emulation resizing */
};

/* Forward declarations */

class CCluster;


/* Class definition */

class CTermPane : public CPanorama {

protected:

	/* Class Variables */
	
	static CCluster	*cTermList;
	
	/* Instance Variables */

	TermHandle		itsTerm;
	
	void	changedConfig(void);

public:

	/* Class Methods */
	
	static OSErr		cCheckToolName(Str63 toolName);
	static void			cInitManager(void);
	static short		cGetTMVersion(void);
	static void			cTermIdle(void);
	static Boolean		cTestToolMenu(short theMenu, short theItem);
	static Boolean		cTestToolEvent(EventRecord *macEvent, 
							WindowPtr theWindow);
	
	/* Instance Methods */
	
	void				ITermPane(CView *anEnclosure, CBureaucrat *aSupervisor,
							Str63 toolName,TMFlags flags,ProcPtr sendProc,
							ProcPtr cacheProc,ProcPtr breakProc,ProcPtr clickLoop,
							ProcPtr environsProc,long refCon,long userData);
	virtual void		Dispose(void);
	virtual void		Draw(Rect *area);
	virtual void		DoCommand(long theCommand);
	virtual void		UpdateMenus(void);
	virtual void		DoIdle(void);
	virtual void		AdjustCursor(Point where,RgnHandle mouseRgn);	
	virtual void		Activate(void);
	virtual void		Deactivate(void);
	virtual void		DoClick(Point hitPt,short modifierKeys,long when);
	virtual void		ResizeFrame(Rect *delta);
	virtual void		DoKeyDown(char theChar,Byte keyCode,
							EventRecord	*macEvent);
	virtual void		DoAutoKey(char theChar,Byte keyCode,
							EventRecord	*macEvent);
	virtual short		SetConfig(char *theConfig);
	virtual void		GetToolName(Str63 toolName);
	virtual Ptr			GetConfig(void);
	virtual Boolean		DoMenu(short theMenu,short theItem);
	virtual Boolean		DoEvent(EventRecord *theEvent,WindowPtr theWindow);
	virtual TermHandle	GetTermHandle(void);
	virtual long		DoStream(Ptr buffer,long buffSize,CMFlags flags);
	virtual void		TermClear(void);
	virtual void		Reset(void);
	virtual void		DoTabCopy(void);
	virtual void		GetExtent(long *theHExtent,long *theVExtent);
	virtual OSErr		GetEnvirons(TermEnvironRec *theEnvirons);
	virtual void		GetLine(short lineNo,TermDataBlock *theTermData);
	virtual void		Scroll(long hDelta,long vDelta,Boolean redraw);
	virtual void		TypeChar(unsigned char theChar);
	virtual void		DoSelectAll(void);
	virtual void		TermChoose(void);
};


/*  */
